@@ -4,9 +4,7 @@ from .. import Provider as LoremProvider
 class Provider(LoremProvider):
     """Implement lorem provider for ``pl_PL`` locale.
 
-    Sources:
-
-    - https://pl.wiktionary.org/wiki/Indeks:Polski_-_Najpopularniejsze_s%C5%82owa_1-2000
+    Source: https://pl.wiktionary.org/wiki/Indeks%3APolski_-_Najpopularniejsze_s%C5%82owa_1-2000
     """
 
     word_list = (
